@@ -1,5 +1,6 @@
+from datetime import datetime
 from functools import lru_cache
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 from kubernetes.client import V1PodSpec, V1Container, V1Scale, V1ScaleSpec, V1Deployment
 
@@ -62,8 +63,8 @@ class KatDep(KatRes):
     statuses = [p.ternary_status() for p in self.pods()]
     if len(set(statuses)) == 1:
       return statuses[0]
-    elif len(set(statuses)) > 1:
-      return 'negative' if 'negative' in statuses else 'pending'
+    # elif len(set(statuses)) > 1:
+    #   return 'negative' if 'negative' in statuses else 'pending'
     else:
       return 'pending'
 
